==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/vco69.cpp <==

/****************************************************************************

  module      : vco69.cpp

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: DCOM Registry auf NT
  description : Registry Functions (REGSVR32)

  last changed: 2000-08-17  16:11

  changed : 17-Aug-2000 PTS 1107355 FF

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include <stdlib.h>
#if defined(NMP)
/* Must be included before gco00.h on this platform... */
#include <wchar.h>
#endif
#include "heo01.h"
#include "heo02x.h"
#include "heo46.h"
#include "gco00.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#define RC_OK                0
#define RC_ERROR             -1


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/

typedef BOOL (*DLLMAIN) (HANDLE hInstance,
                         DWORD  dwReason,
                         char*  szModule);

typedef HRESULT (*DLLREGISTERSERVER)(void);
typedef HRESULT (*DLLUNREGISTERSERVER)(void);


/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL VARIABLES                                                          *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/

void print_call_params () {
  fprintf (stdout, "correct usage of xregcom is:\n\n");
  fprintf (stdout, "xregcomp [-[c|u][s]] <component-lib-name>\n");
  fprintf (stdout, "  c - register (default)\n");
  fprintf (stdout, "  u - unregister\n");
  fprintf (stdout, "  s - silent mode ( no msg to stdout, only returncode will be set )\n");
}

 /*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

int main (int argc, char *argv[])
{
  char              errtext[256];
  tsp00_Pathc       OmsLibPath;
  HANDLE            hd;
  HRESULT           hr;
  char*             pc = NULL;
  char*             pcc;
  bool              bregistrate = true;
  bool              bsilent = false;

  typedef void  (*sqlPROC)();

  //DebugBreak();
  if (( argc < 2 ) || ( argc > 3))
  {
    print_call_params();
    return RC_ERROR;
  }

  if ( pcc = strchr(argv[1],'-'))
  {
    if (pcc && (argc == 3) && (1 < strlen(pcc)) && (4 > strlen(pcc))) 
    {
      if ( strchr(pcc,'u') || strchr(pcc,'c') || strchr(pcc,'s')) {
        if ( strchr(pcc,'u')) {
          bregistrate = false;
        }
        if ( strchr(pcc,'c')) {
          bregistrate = true;
        }
        if ( strchr(pcc,'s')) {
          bsilent = true;
        } 
        pc = argv[2];
      }
      else {
        print_call_params();
        return RC_ERROR;
      }
    }
    else
    {
      print_call_params();
      return RC_ERROR;
    }
  }
  else
    if (argc == 2)
      pc = argv[1];
    else {
      print_call_params();
      return RC_ERROR;
    }

  tsp01_RteError  RteError ;
  eo46_rte_error_init ( &RteError ) ;

  tsp00_Bool        ok;
#if defined(WIN32)
  ok = sqlGetDbrootPgmPath (OmsLibPath, TERM_WITH_DELIMITER_EO01, &RteError );
#else
  ok = sqlGetDbrootLibPath (OmsLibPath, TERM_WITH_DELIMITER_EO01, &RteError );
#endif
  /* PTS 1104841 */
  /*if ( !sqlGetDbrootLibPath(OmsLibPath, TERM_WITH_DELIMITER_EO01, &RteError ) ) { PTS 1107355 */
  if ( !ok ) {
    /*    fprintf (stdout,"environment variable 'DBROOT' isn't defined: %s\n", (char *)RteError.RteErrText); */
    if ( !bsilent )
      fprintf (stdout,"Filepath for 'liboms' couldn't be retrieved : %s\n", (char *)RteError.RteErrText);
    return RC_ERROR;
  }
  strcat(OmsLibPath, "liboms" );
  hd = sqlLoadLibraryEx(OmsLibPath, RTLD_GLOBAL_EO02, errtext, sizeof(errtext));
  if ( hd == 0 )
  {
    if ( !bsilent )
      fprintf (stdout, "Couldn't load library: %s\n%s\n", (char *)OmsLibPath, &errtext[0]);
    return RC_ERROR;
  }

  if ( !bsilent ) {
    int *o78_nosilent_mode = (int*)(/*PTS 1109282*/void*)sqlGetProcAddress(hd, (char*)"o78_nosilent_mode", &errtext[0], sizeof(errtext));
    if ( o78_nosilent_mode ) *o78_nosilent_mode = 1;
  }
  
  hd = sqlLoadLibrary(pc, &errtext[0], sizeof(errtext));
  if ( hd == 0 )
  {
    if ( !bsilent )
      fprintf (stdout, "Couldn't load library: %s\n%s\n", pc, &errtext[0]);
    return RC_ERROR;
  }

#if !defined(WIN32)
  DLLMAIN DllMain = (DLLMAIN)sqlGetProcAddress(hd, (char*)"DllMain", &errtext[0], sizeof(errtext));
  if ( NULL == DllMain )
  {
    if ( !bsilent )
      fprintf (stdout, "Couldn't locate Entry 'DllMain' within library: %s\n", pc);
    return RC_ERROR;
  }

  if ( ! DllMain(hd, DLL_PROCESS_ATTACH, pc))
  {
    if ( !bsilent )
      fprintf (stdout, "Calling 'DllMain' returned error \n");
    return RC_ERROR;
  }
#endif

  if ( bregistrate )
  {
    DLLREGISTERSERVER DllRegisterServer = (DLLREGISTERSERVER)sqlGetProcAddress(hd,
      (char*)"DllRegisterServer", &errtext[0], sizeof(errtext));
    if ( NULL == DllRegisterServer )
    {
      if ( !bsilent )
        fprintf (stdout, "Couldn't locate entry 'DllRegisterServer' within library: %s\n",pc);
      return RC_ERROR;
    }
    hr = DllRegisterServer();
    if (( 0 != hr ) && ( !bsilent ))
      fprintf (stdout, "Calling 'DllRegisterServer' returned error: 0x%X \n", hr);
  }
  else
  {
    DLLUNREGISTERSERVER DllUnregisterServer = (DLLUNREGISTERSERVER)sqlGetProcAddress(hd,
      (char*)"DllUnregisterServer", &errtext[0], sizeof(errtext));
    if ( NULL == DllUnregisterServer )
    {
      if ( !bsilent )
      fprintf (stdout, "Couldn't locate entry 'DllUnregisterServer' within library: %s\n",pc);
      return RC_ERROR;
    }
    hr = DllUnregisterServer();
    if (( 0 != hr ) && ( !bsilent ))
      fprintf (stdout, "Calling 'DllUnregisterServer' returned error: 0x%X \n", hr);
  }
  if (SUCCEEDED(hr) && !bsilent )
  {
    if ( bregistrate )
      fprintf (stdout, "Registration done \n", pc);
    else
      fprintf (stdout, "Registration cleared \n", pc);
    return S_OK;
  }
  if (SUCCEEDED(hr))
    return S_OK;
  else
    return RC_ERROR;
}

/*==========================================================================*/


/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/vco69.cpp <==

/****************************************************************************

  module      : vco69.cpp

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: DCOM Registry auf NT
  description : Registry Functions (REGSVR32)

  last changed: 2000-08-17  16:11

  changed : 17-Aug-2000 PTS 1107355 FF

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include <stdlib.h>
#if defined(NMP)
/* Must be included before gco00.h on this platform... */
#include <wchar.h>
#endif
#include "heo01.h"
#include "heo02x.h"
#include "heo46.h"
#include "gco00.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#define RC_OK                0
#define RC_ERROR             -1


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/

typedef BOOL (*DLLMAIN) (HANDLE hInstance,
                         DWORD  dwReason,
                         char*  szModule);

typedef void (*INITSINGLETONS)();   /* PTS 1116546 */

typedef HRESULT (*DLLREGISTERSERVER)(void);
typedef HRESULT (*DLLUNREGISTERSERVER)(void);
/* +++++ PTS 1110790 FF                     +++++ */
typedef int* (*TRACEFLAG)(void);   
typedef union 
  {
    TRACEFLAG  f_ptr;
    int*       i_ptr;
} t_traceflag;
/* ----- PTS 1110790 FF                     ----- */


/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL VARIABLES                                                          *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/

void print_call_params () {
  fprintf (stdout, "correct usage of xregcom is:\n\n");
  fprintf (stdout, "xregcomp [-[c|u][s]] <component-lib-name>\n");
  fprintf (stdout, "  c - register (default)\n");
  fprintf (stdout, "  u - unregister\n");
  fprintf (stdout, "  s - silent mode ( no msg to stdout, only returncode will be set )\n");
}

 /*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

/* this routine is needed by liboms */
externC void	sql60c_msg_8    ( tsp_int4            msg_no ,
                          tsp_int4            msg_type ,
                          const char         *msg_label ,
                          const char         *msg_format ,
                          ...                           );

externC void	sql60c_msg_8    ( tsp_int4            msg_no ,
                          tsp_int4            msg_type ,
                          const char         *msg_label ,
                          const char         *msg_format ,
                          ...                           )
{

  va_list                         args ;

  va_start ( args, msg_format ) ;
  vprintf (msg_format, args ) ;
  va_end ( args ) ;
  printf("\n");
}

int main (int argc, char *argv[])
{
  char              errtext[256];
  tsp00_Pathc       OmsLibPath;
  HANDLE            hd;
  HRESULT           hr;
  char*             pc = NULL;
  char*             pcc;
  bool              bregistrate = true;
  bool              bsilent = false;

  typedef void  (*sqlPROC)();

  //DebugBreak();
  if (( argc < 2 ) || ( argc > 3))
  {
    print_call_params();
    return RC_ERROR;
  }

  if (( argc == 3 ) && ( pcc = strchr(argv[1],'-')))
  {
    if (pcc && (1 < strlen(pcc)) && (4 > strlen(pcc))) 
    {
      if ( strchr(pcc,'u') || strchr(pcc,'c') || strchr(pcc,'s')) {
        if ( strchr(pcc,'u')) {
          bregistrate = false;
        }
        if ( strchr(pcc,'c')) {
          bregistrate = true;
        }
        if ( strchr(pcc,'s')) {
          bsilent = true;
        } 
        pc = argv[2];
      }
      else {
        print_call_params();
        return RC_ERROR;
      }
    }
    else
    {
      print_call_params();
      return RC_ERROR;
    }
  }
  else
    if (argc == 2)
      pc = argv[1];
    else {
      print_call_params();
      return RC_ERROR;
    }

  tsp01_RteError  RteError ;
  eo46_rte_error_init ( &RteError ) ;

  tsp00_Bool        ok;
#if defined(WIN32)
  ok = sqlGetDbrootPgmPath (OmsLibPath, TERM_WITH_DELIMITER_EO01, &RteError );
#else
  ok = sqlGetDbrootLibPath (OmsLibPath, TERM_WITH_DELIMITER_EO01, &RteError );
#endif
  /* PTS 1104841 */
  /*if ( !sqlGetDbrootLibPath(OmsLibPath, TERM_WITH_DELIMITER_EO01, &RteError ) ) { PTS 1107355 */
  if ( !ok ) {
    /*    fprintf (stdout,"environment variable 'DBROOT' isn't defined: %s\n", (char *)RteError.RteErrText); */
    if ( !bsilent )
      fprintf (stdout,"Filepath for 'liboms' couldn't be retrieved : %s\n", (char *)RteError.RteErrText);
    return RC_ERROR;
  }
  strcat(OmsLibPath, "liboms" );
  hd = sqlLoadLibraryEx(OmsLibPath, RTLD_GLOBAL_EO02, errtext, sizeof(errtext));
  if ( hd == 0 )
  {
    if ( !bsilent )
      fprintf (stdout, "Couldn't load library: %s\n%s\n", (char *)OmsLibPath, &errtext[0]);
    return RC_ERROR;
  }

  /* ++++ PTS 1116546 initialize singletons after loading liboms ++++ */
  INITSINGLETONS initSingletons = (INITSINGLETONS)sqlGetProcAddress(hd, (char*)"co10_initSingletons", &errtext[0], sizeof(errtext));
  if ( NULL == initSingletons )
  {
    if ( !bsilent )
      fprintf (stdout, "Couldn't locate Entry 'co10_initSingletons' within library: %s\n", (char *)OmsLibPath);
    return RC_ERROR;
  }
  initSingletons(); 
  /* ---- PTS 1116546 initialize singletons after loading liboms ---- */

  if ( !bsilent ) {
    /* +++++ PTS 1110790 FF                     +++++ */
    TRACEFLAG o78_nosilent_mode = (TRACEFLAG)sqlGetProcAddress(hd, (char*)"o78_nosilent_mode", &errtext[0], sizeof(errtext)); /*PTS +++ */
    if ( o78_nosilent_mode ) 
    {
      t_traceflag t;
      t.f_ptr = o78_nosilent_mode;
      *t.i_ptr = 1;
    }
    /* ----- PTS 1110790 FF                     ----- */
    // PTS 1110790 FF    *o78_nosilent_mode = (int*)(/*PTS 1109360*/void*)sqlGetProcAddress(hd, (char*)"o78_nosilent_mode", &errtext[0], sizeof(errtext));
    // PTS 1110790 FF    if ( o78_nosilent_mode ) *o78_nosilent_mode = 1;
  }
  
  hd = sqlLoadLibrary(pc, &errtext[0], sizeof(errtext));
  if ( hd == 0 )
  {
    if ( !bsilent )
      fprintf (stdout, "Couldn't load library: %s\n%s\n", pc, &errtext[0]);
    return RC_ERROR;
  }

#if !defined(WIN32)
  DLLMAIN DllMain = (DLLMAIN)sqlGetProcAddress(hd, (char*)"DllMain", &errtext[0], sizeof(errtext));
  if ( NULL == DllMain )
  {
    if ( !bsilent )
      fprintf (stdout, "Couldn't locate Entry 'DllMain' within library: %s\n", pc);
    return RC_ERROR;
  }

  if ( ! DllMain(hd, DLL_PROCESS_ATTACH, pc))
  {
    if ( !bsilent )
      fprintf (stdout, "Calling 'DllMain' returned error \n");
    return RC_ERROR;
  }
#endif

  if ( bregistrate )
  {
    DLLREGISTERSERVER DllRegisterServer = (DLLREGISTERSERVER)sqlGetProcAddress(hd,
      (char*)"DllRegisterServer", &errtext[0], sizeof(errtext));
    if ( NULL == DllRegisterServer )
    {
      if ( !bsilent )
        fprintf (stdout, "Couldn't locate entry 'DllRegisterServer' within library: %s\n",pc);
      return RC_ERROR;
    }
    hr = DllRegisterServer();
    if (( 0 != hr ) && ( !bsilent ))
      fprintf (stdout, "Calling 'DllRegisterServer' returned error: 0x%X \n", hr);
  }
  else
  {
    DLLUNREGISTERSERVER DllUnregisterServer = (DLLUNREGISTERSERVER)sqlGetProcAddress(hd,
      (char*)"DllUnregisterServer", &errtext[0], sizeof(errtext));
    if ( NULL == DllUnregisterServer )
    {
      if ( !bsilent )
      fprintf (stdout, "Couldn't locate entry 'DllUnregisterServer' within library: %s\n",pc);
      return RC_ERROR;
    }
    hr = DllUnregisterServer();
    if (( 0 != hr ) && ( !bsilent ))
      fprintf (stdout, "Calling 'DllUnregisterServer' returned error: 0x%X \n", hr);
  }
  if (SUCCEEDED(hr) && !bsilent )
  {
    if ( bregistrate )
      fprintf (stdout, "Registration done \n", pc);
    else
      fprintf (stdout, "Registration cleared \n", pc);
    return S_OK;
  }
  if (SUCCEEDED(hr))
    return S_OK;
  else
    return RC_ERROR;
}

/*==========================================================================*/


/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
